﻿/*
 * XPT2046_TP_Access.h
 *
 *  Created on: 2024/11/18
 *      Author: egaono-electronics
 */

#ifndef XPT2046_TP_ACCESS_H_
#define XPT2046_TP_ACCESS_H_

#include "Dev_Conf.h"

#include def_Header_HAL



//--------------------------------------------------
// タッチパネル制御IC : XPT2046使用
//--------------------------------------------------


#define def_Only_TouchPanel_XY



#define def_Count_TP_ON  5
                // タッチされた状態を検出するための規定回数
#define def_Count_TP_OFF  5
            // タッチされていない状態を検出するための規定回数


#define def_Time_Convert_TP    0  // 変換時間待ち

#define def_Time_Interval_TP  50
    // タッチされていない状態になった場合の処理終了待ち時間



//--------------------------------------
// XPT2046のPower=Downコマンド
//--------------------------------------
#define def_Command_TP_PD  0x80;


//--------------------------------------
// XPT2046のX値取得コマンド
//--------------------------------------
#define def_Command_TP_X    0xD0;


//--------------------------------------
// XPT2046のY値取得コマンド
//--------------------------------------
#define def_Command_TP_Y    0x90;


//--------------------------------------
// XPT2046のZ1値取得コマンド
//--------------------------------------
#define def_Command_TP_Z1  0xB0;

//--------------------------------------
// XPT2046のZ2値取得コマンド
//--------------------------------------
#define def_Command_TP_Z2  0xC0;



// Touch Panel 終了判定Timer値
#define def_Timer_TP_End    100

// Touch Panel インターバル監視Timer値
#define def_Timer_TP_Interval  (def_Timer_TP_End + 100)


// Bufferに取り込んだタッチ位置データの変動許容最大値
#define def_MAX_Diff_TP    200



//----------------------------------------------------------
// タッチパネルの位置取得のためのパラメータ : 通常用
//----------------------------------------------------------
// 位置データを取り込み始めるまでに、捨てるデータ数
#define def_Number_TP_Idle  16


//------------------------------------------
// 位置データ取得において捨てる部分の定義
//------------------------------------------
// X と Y において、F と R の合計は一致していなければならない。
//------------------------------------------
#define def_Number_TP_Except_F  32
                            // 位置データを捨てる前半部分の数
#define def_Number_TP_Except_R  8
                            // 位置データを捨てる後半部分の数
//------------------------------------------


// 平均値の個数
#define def_Number_TP_Average  16


// Touch Panel の XY位置の平均値を求めるデータ配列の開始位置
#define def_Start_TP_Average  def_Number_TP_Except_F

// Touch Panel の XY位置の平均値を求めるデータ配列の終了位置
#define def_End_TP_Average  \
        (def_Number_TP_Except_F + def_Number_TP_Average - 1)

// Touch Panel XY位置算出のためのデータ取得数
// 捨てるデータ前半部分 + 平均値を算出するデータ
//          32          +           16
//                                   + 捨てるデータ後半部分
//                                   +          8          = 56
#define def_Number_Get_TP_XY  \
(def_Number_TP_Except_F + def_Number_TP_Average\
                                     + def_Number_TP_Except_R)


//--------------------------------------------------
// Touch Panel 位置検出用Bufferのサイズ
//--------------------------------------------------
#define def_Size_TP_Buffer  def_Number_Get_TP_XY
//----------------------------------------------------------



//----------------------------------------------------------
// タッチパネルの位置取得のためのパラメータ : 調整用
//----------------------------------------------------------
// 位置データを取り込み始めるまでに、捨てるデータ数 : 調整用
#define def_Number_Adjust_TP_Idle  16


//------------------------------------------
// 位置データ取得において捨てる部分の定義 : 調整用
//------------------------------------------
// X と Y において、F と R の合計は一致していなければならない。
//------------------------------------------
#define def_Number_Adjust_TP_Except_F  64
                    // 位置データを捨てる前半部分の数 : 調整用
#define def_Number_Adjust_TP_Except_R  16
                    // 位置データを捨てる後半部分の数 : 調整用
//------------------------------------------


// 平均値の個数 : 調整用
#define def_Number_Adjust_TP_Average  32


// Touch Panel の XY位置の平均値を求める
//                      データ配列の開始位置 : 調整用
#define def_Start_Adjust_TP_Average  \
                            def_Number_Adjust_TP_Except_F

// Touch Panel の XY位置の平均値を求める
//                      データ配列の終了位置 : 調整用
#define def_End_Adjust_TP_Average  \
    (def_Number_Adjust_TP_Except_F \
                    + def_Number_Adjust_TP_Average - 1)

// Touch Panel XY位置算出のためのデータ取得数 : 調整用
// 捨てるデータ前半部分 + 平均値を算出するデータ
//          64          +           32
//                      + 捨てるデータ後半部分
//                      +          16          = 112
#define def_Number_Get_Adjust_TP_XY  \
(def_Number_Adjust_TP_Except_F + def_Number_Adjust_TP_Average\
                               + def_Number_Adjust_TP_Except_R)


//----------------------------------------------------
// Touch Panel 位置検出用Bufferのサイズ : 調整用
//----------------------------------------------------
#define def_Size_Adjust_TP_Buffer  \
                            def_Number_Get_Adjust_TP_XY
//----------------------------------------------------------



//------------------------------------------------------
// タッチパネル位置取得用パラメータの構造体
//------------------------------------------------------
struct sParam_Position_TP{
  //------------------------------------------------------------
  // 位置取得パラメータ
  //------------------------------------------------------------
  int16_t int16_Number_TP_Idle;  // 最初の位置データを捨てる回数
  int16_t int16_Size_TP_Buffer;  // TPバッファのサイズ
  int16_t int16_Number_Get_TP_XY;  // TPデータ取得規定回数
  int16_t int16_Number_TP_Average;  // TP平均個数
  int16_t int16_Number_TP_Except_F;  // TPデータ除外個数
  int16_t int16_Start_TP_Average;  // TPデータ平均開始位置
  int16_t int16_End_TP_Average;  // TPデータ平均終了位置
  //------------------------------------------------------------


  uint16_t uint16_aTP_Buffer_X[def_Size_Adjust_TP_Buffer];
                        // Touch Panel のX位置取得用Buffer
  uint16_t uint16_aTP_Buffer_Y[def_Size_Adjust_TP_Buffer];
                        // Touch Panel のY位置取得用Buffer

  uint16_t uint16_Position_TP_Buffer;
                // Touch Panel の位置取得用Bufferの格納位置


  int16_t int16_aSort[def_Size_Adjust_TP_Buffer];
                                    // TPデータSort用Buffer


  //--------------------------------------------------------
  // Touch Panel のXとYの取得位置を格納するBuffer
  //--------------------------------------------------------
  // uint16_aPosition_TP_XYZ[0] : X位置
  // uint16_aPosition_TP_XYZ[1] : Y位置
  // uint16_aPosition_TP_XYZ[2] : Z1位置
  // uint16_aPosition_TP_XYZ[3] : Z2位置
  //--------------------------------------------------------
  uint16_t uint16_aPosition_TP_XYZ[8];


  uint16_t uint16_Position_TP_X;
                // タッチパネルのX位置 : 長手方向をXとする。
  uint16_t uint16_Position_TP_Y;
                // タッチパネルのY位置 : 短手方向をYとする。


  volatile int16_t int16_vTimer_TP_Interval;
                                // タッチパネル監視タイマ
};



//-------------------------------------
// XPT2046初期化
//-------------------------------------
void Initialize_XPT2046(void);



//----------------------------------------------------------
// Touch Panel 位置取得
//----------------------------------------------------------
// 引数;
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// struct sParam_Position_TP *pstructParam_Position_TP :
//      タッチパネル位置取得用パラメータの構造体のポインタ


// 戻り値;
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Get_Position_TouchPanel(uint8_t *puint8_JobNum,
        struct sParam_Position_TP *pstructParam_Position_TP);



//----------------------------------------------------------
// Touch PanelのXYZ位置取得
//----------------------------------------------------------
// 引数;
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// struct sParam_Position_TP *pstructParam_Position_TP :
//      タッチパネル位置取得用パラメータの構造体のポインタ


// 戻り値;
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//    2 : TP OFF
//----------------------------------------------------------
int16_t Get_XYZ_TP(uint8_t *puint8_JobNum,
        struct sParam_Position_TP *pstructParam_Position_TP);



//----------------------------------------------------------
// Touch PanelのXY位置データ取得
//----------------------------------------------------------
// 引数;
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// uint16_t *puint16_aTP_Buffer_X :
//                          X位置を格納するBufferのポインタ
// uint16_t *puint16_aTP_Buffer_Y :
//                          Y位置を格納するBufferのポインタ
// uint16_t uint16_Position_TP_Buffer : Buffer格納位置


// 戻り値;
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Get_Data_XY_TP(uint8_t *puint8_JobNum,
                       uint16_t *puint16_aTP_Buffer_X,
                       uint16_t *puint16_aTP_Buffer_Y,
                       uint16_t uint16_Position_TP_Buffer);



//------------------------------------------------------
// タッチパネル位置取得用パラメータの構造体の宣言
//------------------------------------------------------
extern struct sParam_Position_TP GLB_structParam_Position_TP;



#endif /* XPT2046_TP_ACCESS_H_ */
