/*
 * MSP2807_Test_TP.c
 *
 *  Created on: 2025/02/25
 *      Author: egaono-electronics
 */

#include "MSP2807_Test_TP.h"

#include "ILI9341_SPI_Init.h"

#include "MSP2807_Startup_Screen_Test_TP.h"
#include "ILI9341_Display_Clear.h"
#include "ILI9341_Display_ASCII.h"

#include "MSP2807_Test_TP_Key_In.h"


#include <string.h>



uint16_t GLB_uint16_Num_Data_Input;  // 入力データ数

// 入力データBuffer
uint8_t GLB_uint8_aData_Input[(int16_t)def_Size_TP_Key_Data_Buffer];



//--------------------------------------------------------------
// MSP2807のタッチパネル試験
//--------------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納された変数のポインタ

// struct sParam_Position_TP *pstructParam_Position_TP :
//          タッチパネル位置取得用パラメータの構造体のポインタ

// struct sParam_Adjust_TP *pstructParam_Adjust_TP :
//          タッチパネル位置調整用パラメータ構造体のポインタ

// struct sParam_TP_SW *pstructParam_TP_SW :
//          タッチパネルスイッチ用パラメータの構造体のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//--------------------------------------------------------------
int16_t MSP2807_Test_TP(uint8_t *puint8_JobNum,
            struct sParam_Position_TP *pstructParam_Position_TP,
            struct sParam_Adjust_TP *pstructParam_Adjust_TP,
            struct sParam_TP_SW *pstructParam_TP_SW)
{
  static uint8_t STC_uint8_JobNum_MSP2807;  // MSP2807処理番号

  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_MSP2807 = 0;  // MSP2807処理番号初期化


    //--------------------------------------------------
    // タッチパネルのパラメータ初期化
    //--------------------------------------------------

    //------------------------------------------
    // XPT2046初期化フラグ
    //------------------------------------------
    //    0 : 未初期化
    //    1 : 初期化済み
    //------------------------------------------------------
    pstructParam_Adjust_TP->int16_Initialize_XPT2046 = 0;
    //------------------------------------------------------



    //--------------------------------------------------------------
    // タッチパネルの位置調整用のXY検出値
    //--------------------------------------------------------------
    pstructParam_Adjust_TP->int16_Adjust_TP_X_1 = -1;
                                        // タッチパネル調整位置_X_1
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_1 = -1;
                                        // タッチパネル調整位置_Y_1

    pstructParam_Adjust_TP->int16_Adjust_TP_X_2 = -1;
                                        // タッチパネル調整位置_X_2
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_2 = -1;
                                        // タッチパネル調整位置_Y_2

    pstructParam_Adjust_TP->int16_Adjust_TP_X_3 = -1;
                                        // タッチパネル調整位置_X_3
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_3 = -1;
                                        // タッチパネル調整位置_Y_3

    pstructParam_Adjust_TP->int16_Adjust_TP_X_4 = -1;
                                        // タッチパネル調整位置_X_4
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_4 = -1;
                                        // タッチパネル調整位置_Y_4
    //--------------------------------------------------------------



    //--------------------------------------------------------------
    // タッチパネル調整用XY最大最小値
    //--------------------------------------------------------------
    // 最小値
    pstructParam_Adjust_TP->int16_Adjust_TP_X_MIN = -1;
                                    // タッチパネル調整位置_X_最小値
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_MIN = -1;
                                    // タッチパネル調整位置_Y_最小値


    // 最大値
    pstructParam_Adjust_TP->int16_Adjust_TP_X_MAX = -1;
                                    // タッチパネル調整位置_X_最大値
    pstructParam_Adjust_TP->int16_Adjust_TP_Y_MAX = -1;
                                    // タッチパネル調整位置_Y_最大値
    //--------------------------------------------------------------


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //--------------------------------------------------------------
    // ILI9341初期化
    //--------------------------------------------------------------
    // 戻り値：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //--------------------------------------------------------------
    int16_Return = ILI9341_Initialize(&STC_uint8_JobNum_MSP2807);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      break;  // 処理番号維持 : 処理継続
      // 初期化が正常に終了しない場合、ここから下の処理に進まない。
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //--------------------------------------------------------------
    // タッチパネル試験 MSP2807起動画面表示 : Touch Panel : ASCII
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //--------------------------------------------------------------
    int16_Return
        = MSP2807_Startup_Screen_Test_TP(&STC_uint8_JobNum_MSP2807);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //--------------------------------------------------------------
    // タッチパネルの位置調整
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Position_TP *pstructParam_Position_TP :
    //              タッチパネル位置取得用パラメータの構造体のポインタ

    // struct sParam_Adjust_TP *pstructParam_Adjust_TP :
    //              タッチパネル位置調整用パラメータ構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //--------------------------------------------------------------
    int16_Return = Transact_Adjust_TP(&STC_uint8_JobNum_MSP2807,
                                      pstructParam_Position_TP,
                                      pstructParam_Adjust_TP);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 4:
    //--------------------------------------------------------------
    // タッチパネル上のアルファニューメリックデータ入力
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納された変数のポインタ

    // struct sParam_Position_TP *pstructParam_Position_TP :
    //          タッチパネル位置取得用パラメータの構造体のポインタ

    // struct sParam_Adjust_TP *pstructParam_Adjust_TP :
    //              タッチパネル位置調整用パラメータ構造体のポインタ

    // struct sParam_TP_SW *pstructParam_TP_SW :
    //              タッチパネルスイッチ用パラメータの構造体のポインタ

    // uint16_t *puint16_Num_Data_Input :
    //                      入力データ数を格納するWorkのポインタ
    // uint8_t *puint8_Data : Dataを格納するBufferのポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //--------------------------------------------------------------
    int16_Return = Input_Data_AN_Test_TP(&STC_uint8_JobNum_MSP2807,
                                         pstructParam_Position_TP,
                                         pstructParam_Adjust_TP,
                                         pstructParam_TP_SW,
                                         &GLB_uint16_Num_Data_Input,
                                         GLB_uint8_aData_Input);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      int16_Return = -1;  // 処理中をセット
      break;  // 処理番号維持 : 処理継続
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
        // タッチパネル上のアルファニューメリックデータ入力に対する処理
    int16_Return = -1;   // 処理継続
    break;

  case 5:
    // タッチパネル上のアルファニューメリックデータ入力に対する処理

    // この例では、入力データを 32 x 32 のサイズで表示する。
    //----------------------------------------------------------
    // タッチパネルの入力データを表示する。
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // int16_t uint16_Num_Data_Input : データ長
    // uint8_t *puint8_aData_Buffer :
    //                  入力Dataが格納されているBufferのポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Draw_TP_SW_Input_Data(&STC_uint8_JobNum_MSP2807,
                                         GLB_uint16_Num_Data_Input,
                                         GLB_uint8_aData_Input);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
        // タッチパネル上のアルファニューメリックデータ入力に対する処理
    int16_Return = -1;   // 処理継続
    break;

  case 6:
    //--------------------------------------------------------------
    // LCD画面がタッチされるのを待つ。
    //--------------------------------------------------------------

    //--------------------------------------------------------------
    // Touch Panel 位置取得
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Position_TP *pstructParam_Position_TP :
    //          タッチパネル位置取得用パラメータの構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //--------------------------------------------------------------
    int16_Return = Get_Position_TouchPanel(&STC_uint8_JobNum_MSP2807,
                                           pstructParam_Position_TP);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG終了
    break;
  }

  return(int16_Return);
}


//--------------------------------------------------------------
// タッチパネルの入力データを表示する。
//--------------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

// int16_t uint16_Num_Data_Input : データ長
// uint8_t *puint8_aData_Buffer :
//                  入力Dataが格納されているBufferのポインタ

// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//--------------------------------------------------------------
int16_t Draw_TP_SW_Input_Data(uint8_t *puint8_JobNum,
                               uint16_t uint16_Num_Data_Input,
                               uint8_t *puint8_aData_Buffer)
{
  static uint8_t STC_uint8_JobNum_LCD;

  static uint16_t STC_uint16_Num_Data_Input;
  static uint16_t STC_uint16_Draw_Length;
  static uint16_t STC_uint16_Draw_Data_Position;

  static uint16_t STC_uint16_StartX;
  static uint16_t STC_uint16_StartY;

  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_LCD = 0;  // LCD表示処理番号初期化

    STC_uint16_Num_Data_Input = uint16_Num_Data_Input;
                                        // 表示データ数を保存
    STC_uint16_Draw_Data_Position = 0;

    STC_uint16_StartX = 0;
    STC_uint16_StartY = 0;


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //--------------------------------------------------------------
    // 画面表示をクリアする。
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //--------------------------------------------------------------
    int16_Return = Clear_Display(&STC_uint8_JobNum_LCD);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      *puint8_JobNum = 0;  // 処理番号初期化
      break;  // NG終了
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //------------------------------------------------
    // 32x32dot の文字を、
    // 一行に表示できる文字数が 10 なので、
    // データ数が 10 文字を超える場合は、
    // 表示文字数に 10 をセットする。
    //------------------------------------------------
    if(STC_uint16_Num_Data_Input > 10){
      STC_uint16_Draw_Length = 10;
    }
    else{
      STC_uint16_Draw_Length = STC_uint16_Num_Data_Input;
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //-------------------------------
    // 入力データ表示
    //-------------------------------
    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    //--------------------------------------------------------------
    // LCD文字表示 : ASCII : Font選択 : ILI9341
    //--------------------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                    1,
                    (uint16_t)def_Font_ASCII_Expand_32x32,
                    def_WidthwiseL, 0,
                    (uint32_t)def_Code_Violet,
                    STC_uint16_StartX, STC_uint16_StartY,
                    STC_uint16_Draw_Length,
                    &puint8_aData_Buffer[STC_uint16_Draw_Data_Position]);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;
    }


    // 表示済みの文字数を差し引く。
    STC_uint16_Num_Data_Input -= STC_uint16_Draw_Length;
    if(STC_uint16_Num_Data_Input > 0){
      // データをすべて表示していない場合
      STC_uint16_StartY += 32;  // 次の行位置をセット
      STC_uint16_Draw_Data_Position += 10;  // 表示データ位置を更新

      (*puint8_JobNum)--;  // 次の処理番号に移行する。
      int16_Return = -1;   // 処理継続
      break;
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;
  }

  return(int16_Return);
}
